[gimp] plug-ins: various s/save/export/ replacement on visible strings.



commit ec27b539eaeeeb629e40ee92801ec67d9b04f8cc
Author: Jehan <jehan girinstud io>
Date:   Tue Feb 16 02:35:43 2016 +0100

    plug-ins: various s/save/export/ replacement on visible strings.

 plug-ins/common/file-cel.c          |   10 ++++----
 plug-ins/common/file-gbr.c          |   14 +++++-----
 plug-ins/common/file-gif-save.c     |   36 ++++++++++++++--------------
 plug-ins/common/file-gih.c          |   16 ++++++------
 plug-ins/common/file-html-table.c   |   12 ++++----
 plug-ins/common/file-pat.c          |   14 +++++-----
 plug-ins/common/file-pcx.c          |   12 ++++----
 plug-ins/common/file-pix.c          |   14 +++++-----
 plug-ins/common/file-png.c          |   44 +++++++++++++++++-----------------
 plug-ins/common/file-pnm.c          |   40 ++++++++++++++++----------------
 plug-ins/common/file-ps.c           |   20 ++++++++--------
 plug-ins/common/file-psp.c          |   26 ++++++++++----------
 plug-ins/common/file-sunras.c       |   18 +++++++-------
 plug-ins/common/file-tga.c          |   12 ++++----
 plug-ins/common/file-xbm.c          |   18 +++++++-------
 plug-ins/common/file-xmc.c          |   20 ++++++++--------
 plug-ins/common/file-xpm.c          |   12 ++++----
 plug-ins/common/file-xwd.c          |   18 +++++++-------
 plug-ins/file-bmp/bmp-write.c       |    6 ++--
 plug-ins/file-fits/fits.c           |   16 ++++++------
 plug-ins/file-fli/fli-gimp.c        |   14 +++++-----
 plug-ins/file-ico/ico-save.c        |    4 +-
 plug-ins/file-jpeg/jpeg-save.c      |    4 +-
 plug-ins/file-psd/psd-save.c        |   24 +++++++++---------
 plug-ins/file-sgi/sgi.c             |   18 +++++++-------
 plug-ins/file-tiff/file-tiff-save.c |    6 ++--
 26 files changed, 224 insertions(+), 224 deletions(-)
---
diff --git a/plug-ins/common/file-cel.c b/plug-ins/common/file-cel.c
index 75f3e20..b0495ac 100644
--- a/plug-ins/common/file-cel.c
+++ b/plug-ins/common/file-cel.c
@@ -97,8 +97,8 @@ query (void)
   {
     { GIMP_PDB_INT32,    "run-mode",         "The run mode { RUN-INTERACTIVE (0), RUN-NONINTERACTIVE (1) }" 
},
     { GIMP_PDB_IMAGE,    "image",            "Input image"                  },
-    { GIMP_PDB_DRAWABLE, "drawable",         "Drawable to save"             },
-    { GIMP_PDB_STRING,   "filename",         "Filename to save image to"    },
+    { GIMP_PDB_DRAWABLE, "drawable",         "Drawable to export"           },
+    { GIMP_PDB_STRING,   "filename",         "Filename to export image to"  },
     { GIMP_PDB_STRING,   "raw-filename",     "Name entered"                 },
     { GIMP_PDB_STRING,   "palette-filename", "Filename to save palette to"  },
   };
@@ -122,8 +122,8 @@ query (void)
                                     "0,string,KiSS\\040");
 
   gimp_install_procedure (SAVE_PROC,
-                          "Saves files in KISS CEL file format",
-                          "This plug-in saves individual KISS cell files.",
+                          "Exports files in KISS CEL file format",
+                          "This plug-in exports individual KISS cell files.",
                           "Nick Lamb",
                           "Nick Lamb <njl195 zepler org uk>",
                           "May 1998",
@@ -770,7 +770,7 @@ save_image (GFile   *file,
   width  = gegl_buffer_get_width  (buffer);
   height = gegl_buffer_get_height (buffer);
 
-  gimp_progress_init_printf (_("Saving '%s'"),
+  gimp_progress_init_printf (_("Exporting '%s'"),
                              gimp_file_get_utf8_name (file));
 
   output = G_OUTPUT_STREAM (g_file_replace (file,
diff --git a/plug-ins/common/file-pix.c b/plug-ins/common/file-pix.c
index 9f7fe07..0e9940e 100644
--- a/plug-ins/common/file-pix.c
+++ b/plug-ins/common/file-pix.c
@@ -31,7 +31,7 @@
  */
 
 /* Features
- *  - loads and saves
+ *  - loads and exports
  *    - 24-bit (.pix)
  *    - 8-bit (.matte, .alpha, or .mask) images
  *
@@ -129,9 +129,9 @@ query (void)
   {
     { GIMP_PDB_INT32,    "run-mode",     "The run mode { RUN-INTERACTIVE (0), RUN-NONINTERACTIVE (1) }" },
     { GIMP_PDB_IMAGE,    "image",        "Input image"                  },
-    { GIMP_PDB_DRAWABLE, "drawable",     "Drawable to save"             },
-    { GIMP_PDB_STRING,   "filename",     "The name of the file to save the image in" },
-    { GIMP_PDB_STRING,   "raw-filename", "The name of the file to save the image in" }
+    { GIMP_PDB_DRAWABLE, "drawable",     "Drawable to export"           },
+    { GIMP_PDB_STRING,   "filename",     "The name of the file to export the image in" },
+    { GIMP_PDB_STRING,   "raw-filename", "The name of the file to export the image in" }
   };
 
   gimp_install_procedure (LOAD_PROC,
@@ -151,8 +151,8 @@ query (void)
   gimp_register_load_handler (LOAD_PROC, "pix,matte,mask,alpha,als", "");
 
   gimp_install_procedure (SAVE_PROC,
-                          "save file in the Alias|Wavefront pix/matte file format",
-                          "save file in the Alias|Wavefront pix/matte file format",
+                          "export file in the Alias|Wavefront pix/matte file format",
+                          "export file in the Alias|Wavefront pix/matte file format",
                           "Michael Taylor",
                           "Michael Taylor",
                           "1997",
@@ -533,7 +533,7 @@ save_image (GFile   *file,
   guchar        *src;
   guchar        *src_base;
 
-  gimp_progress_init_printf (_("Saving '%s'"),
+  gimp_progress_init_printf (_("Exporting '%s'"),
                              g_file_get_parse_name (file));
 
   output = G_OUTPUT_STREAM (g_file_replace (file,
diff --git a/plug-ins/common/file-pnm.c b/plug-ins/common/file-pnm.c
index 73f60a0..8a1e3a3 100644
--- a/plug-ins/common/file-pnm.c
+++ b/plug-ins/common/file-pnm.c
@@ -101,7 +101,7 @@ struct _PNMRowInfo
   gboolean       zero_is_black; /* index zero is black (PBM only) */
 };
 
-/* Save info  */
+/* Export info  */
 typedef struct
 {
   gint  raw;            /*  raw or ascii  */
@@ -240,9 +240,9 @@ query (void)
   {
     { GIMP_PDB_INT32,    "run-mode",     "The run mode { RUN-INTERACTIVE (0), RUN-NONINTERACTIVE (1) }" },
     { GIMP_PDB_IMAGE,    "image",        "Input image"                  },
-    { GIMP_PDB_DRAWABLE, "drawable",     "Drawable to save"             },
-    { GIMP_PDB_STRING,   "filename",     "The name of the file to save the image in" },
-    { GIMP_PDB_STRING,   "raw-filename", "The name of the file to save the image in" },
+    { GIMP_PDB_DRAWABLE, "drawable",     "Drawable to export"           },
+    { GIMP_PDB_STRING,   "filename",     "The name of the file to export the image in" },
+    { GIMP_PDB_STRING,   "raw-filename", "The name of the file to export the image in" },
     { GIMP_PDB_INT32,    "raw",          "TRUE for raw output, FALSE for ascii output" }
   };
 
@@ -250,9 +250,9 @@ query (void)
   {
     { GIMP_PDB_INT32,    "run-mode",     "The run mode { RUN-INTERACTIVE (0), RUN-NONINTERACTIVE (1) }" },
     { GIMP_PDB_IMAGE,    "image",        "Input image"                  },
-    { GIMP_PDB_DRAWABLE, "drawable",     "Drawable to save"             },
-    { GIMP_PDB_STRING,   "filename",     "The name of the file to save the image in" },
-    { GIMP_PDB_STRING,   "raw-filename", "The name of the file to save the image in" }
+    { GIMP_PDB_DRAWABLE, "drawable",     "Drawable to export"           },
+    { GIMP_PDB_STRING,   "filename",     "The name of the file to export the image in" },
+    { GIMP_PDB_STRING,   "raw-filename", "The name of the file to export the image in" }
   };
 
   gimp_install_procedure (LOAD_PROC,
@@ -278,8 +278,8 @@ query (void)
                                     "0,string,PF,0,string,Pf");
 
   gimp_install_procedure (PNM_SAVE_PROC,
-                          "Saves files in the PNM file format",
-                          "PNM saving handles all image types without transparency.",
+                          "Exports files in the PNM file format",
+                          "PNM exporting handles all image types without transparency.",
                           "Erik Nygren",
                           "Erik Nygren",
                           "1996",
@@ -290,8 +290,8 @@ query (void)
                           save_args, NULL);
 
   gimp_install_procedure (PBM_SAVE_PROC,
-                          "Saves files in the PBM file format",
-                          "PBM saving produces mono images without transparency.",
+                          "Exports files in the PBM file format",
+                          "PBM exporting produces mono images without transparency.",
                           "Martin K Collins",
                           "Erik Nygren",
                           "2006",
@@ -302,8 +302,8 @@ query (void)
                           save_args, NULL);
 
   gimp_install_procedure (PGM_SAVE_PROC,
-                          "Saves files in the PGM file format",
-                          "PGM saving produces grayscale images without transparency.",
+                          "Exports files in the PGM file format",
+                          "PGM exporting produces grayscale images without transparency.",
                           "Erik Nygren",
                           "Erik Nygren",
                           "1996",
@@ -314,8 +314,8 @@ query (void)
                           save_args, NULL);
 
   gimp_install_procedure (PPM_SAVE_PROC,
-                          "Saves files in the PPM file format",
-                          "PPM saving handles RGB images without transparency.",
+                          "Exports files in the PPM file format",
+                          "PPM exporting handles RGB images without transparency.",
                           "Erik Nygren",
                           "Erik Nygren",
                           "1996",
@@ -326,8 +326,8 @@ query (void)
                           save_args, NULL);
 
   gimp_install_procedure (PFM_SAVE_PROC,
-                          "Saves files in the PFM file format",
-                          "PFM saving handles all images without transparency.",
+                          "Exports files in the PFM file format",
+                          "PFM exporting handles all images without transparency.",
                           "Mukund Sivaraman",
                           "Mukund Sivaraman",
                           "2015",
@@ -1199,11 +1199,11 @@ save_image (GFile     *file,
   /*  Make sure we're not saving an image with an alpha channel  */
   if (gimp_drawable_has_alpha (drawable_ID))
     {
-      g_message (_("Cannot save images with alpha channel."));
+      g_message (_("Cannot export images with alpha channel."));
       goto out;
     }
 
-  gimp_progress_init_printf (_("Saving '%s'"),
+  gimp_progress_init_printf (_("Exporting '%s'"),
                              g_file_get_parse_name (file));
 
   /* open the file */
@@ -1364,7 +1364,7 @@ save_image (GFile     *file,
               break;
 
             default:
-              g_warning ("Images saved as PBM should be black/white");
+              g_warning ("Images exported as PBM should be black/white");
               break;
             }
         }
diff --git a/plug-ins/common/file-xmc.c b/plug-ins/common/file-xmc.c
index 71500ad..465d9b2 100644
--- a/plug-ins/common/file-xmc.c
+++ b/plug-ins/common/file-xmc.c
@@ -308,8 +308,8 @@ query (void)
     {
       { GIMP_PDB_INT32,    "run-mode",     "The run mode { RUN-INTERACTIVE (0), RUN-NONINTERACTIVE (1) }" },
       { GIMP_PDB_IMAGE,    "image",        "Input image"                  },
-      { GIMP_PDB_DRAWABLE, "drawable",     "Drawable to save"             },
-      { GIMP_PDB_STRING,   "filename",     "The name of the file to save the image in" },
+      { GIMP_PDB_DRAWABLE, "drawable",     "Drawable to export"           },
+      { GIMP_PDB_STRING,   "filename",     "The name of the file to export the image in" },
       { GIMP_PDB_STRING,   "raw-filename", "The name entered" },
       /* following elements are XMC specific options */
       { GIMP_PDB_INT32,    "x_hot",        "X-coordinate of hot spot"       },
@@ -365,8 +365,8 @@ query (void)
   gimp_register_thumbnail_loader (LOAD_PROC, LOAD_THUMB_PROC);
 
   gimp_install_procedure (SAVE_PROC,
-                          "Saves files of X11 cursor file",
-                          "This plug-in saves X11 Mouse Cursor (XMC) files",
+                          "Exports files of X11 cursor file",
+                          "This plug-in exports X11 Mouse Cursor (XMC) files",
                           "Takeshi Matsuyama <tksmashiw gmail com>",
                           "Takeshi Matsuyama",
                           "26 May 2009",
@@ -467,7 +467,7 @@ run (const gchar      *name,
     }
   else if (strcmp (name, SAVE_PROC) == 0)
     {
-      DM_XMC("run: save %s\n", name);
+      DM_XMC("run: export %s\n", name);
       run_mode    = param[0].data.d_int32;
       image_ID    = orig_image_ID = param[1].data.d_int32;
       drawable_ID = param[2].data.d_int32;
@@ -1582,10 +1582,10 @@ save_image (const gchar *filename,
                                &save_rgn))
             { /* if hotspot is not on save_rgn */
               g_set_error (error, 0, 0,
-                           _("Cannot save the cursor because the hot spot "
+                           _("Cannot export the cursor because the hot spot "
                              "is not on frame '%s'.\n"
                              "Try to change the hot spot position, "
-                             "layer geometry or save without auto-crop."),
+                             "layer geometry or export without auto-crop."),
                            gimp_any_to_utf8 (framename, -1, NULL));
               return FALSE;
             }
@@ -1745,18 +1745,18 @@ save_image (const gchar *filename,
   /* actual warning about dimensions */
   if (dimension_warn)
     {
-      g_message (_("Your cursor was successfully saved but it contains one or "
+      g_message (_("Your cursor was successfully exported but it contains one or "
                    "more frames whose width or height is more than %ipx.\n"
                    "It will clutter the screen in some environments."),
                    MAX_BITMAP_CURSOR_SIZE);
     }
   if (size_warn)
     {
-      g_message (_("Your cursor was successfully saved but it contains one "
+      g_message (_("Your cursor was successfully exported but it contains one "
                    "or more frames whose nominal size is not supported by "
                    "GNOME settings.\n"
                    "You can satisfy it by checking \"Replace the size of all "
-                   "frames...\" in the save dialog, or your cursor may not "
+                   "frames...\" in the export dialog, or your cursor may not "
                    "appear in GNOME settings."));
     }
   /*
diff --git a/plug-ins/common/file-xpm.c b/plug-ins/common/file-xpm.c
index a187406..85e6a30 100644
--- a/plug-ins/common/file-xpm.c
+++ b/plug-ins/common/file-xpm.c
@@ -153,9 +153,9 @@ query (void)
   {
     { GIMP_PDB_INT32,    "run-mode",      "The run mode { RUN-INTERACTIVE (0), RUN-NONINTERACTIVE (1) }" },
     { GIMP_PDB_IMAGE,    "image",         "Input image" },
-    { GIMP_PDB_DRAWABLE, "drawable",      "Drawable to save" },
-    { GIMP_PDB_STRING,   "filename",      "The name of the file to save the image in" },
-    { GIMP_PDB_STRING,   "raw-filename",  "The name of the file to save the image in" },
+    { GIMP_PDB_DRAWABLE, "drawable",      "Drawable to export" },
+    { GIMP_PDB_STRING,   "filename",      "The name of the file to export the image in" },
+    { GIMP_PDB_STRING,   "raw-filename",  "The name of the file to export the image in" },
     { GIMP_PDB_INT32,    "threshold",     "Alpha threshold (0-255)" }
   };
 
@@ -185,8 +185,8 @@ query (void)
                                     "0, string,/*\\040XPM\\040*/");
 
   gimp_install_procedure (SAVE_PROC,
-                          "Save files in XPM (X11 Pixmap) format.",
-                          "Save files in XPM (X11 Pixmap) format. "
+                          "Export files in XPM (X11 Pixmap) format.",
+                          "Export files in XPM (X11 Pixmap) format. "
                           "XPM is a portable image format designed to be "
                           "included in C source code. XLib provides utility "
                           "functions to read this format. Newer code should "
@@ -657,7 +657,7 @@ save_image (const gchar  *filename,
 
   hash = g_hash_table_new ((GHashFunc) rgbhash, (GCompareFunc) compare);
 
-  gimp_progress_init_printf (_("Saving '%s'"),
+  gimp_progress_init_printf (_("Exporting '%s'"),
                              gimp_filename_to_utf8 (filename));
 
   ncolors = alpha ? 1 : 0;
diff --git a/plug-ins/file-bmp/bmp-write.c b/plug-ins/file-bmp/bmp-write.c
index 562a70b..425ed05 100644
--- a/plug-ins/file-bmp/bmp-write.c
+++ b/plug-ins/file-bmp/bmp-write.c
@@ -194,7 +194,7 @@ WriteBMP (const gchar  *filename,
       break;
 
     case GIMP_GRAYA_IMAGE:
-      if (interactive && !warning_dialog (_("Cannot save indexed image with "
+      if (interactive && !warning_dialog (_("Cannot export indexed image with "
                                             "transparency in BMP file format."),
                                           _("Alpha channel will be ignored.")))
         return GIMP_PDB_CANCEL;
@@ -226,7 +226,7 @@ WriteBMP (const gchar  *filename,
       break;
 
     case GIMP_INDEXEDA_IMAGE:
-      if (interactive && !warning_dialog (_("Cannot save indexed image with "
+      if (interactive && !warning_dialog (_("Cannot export indexed image with "
                                             "transparency in BMP file format."),
                                           _("Alpha channel will be ignored.")))
         return GIMP_PDB_CANCEL;
@@ -315,7 +315,7 @@ WriteBMP (const gchar  *filename,
   gimp_set_data (SAVE_PROC, &BMPSaveData, sizeof (BMPSaveData));
 
   /* Let's begin the progress */
-  gimp_progress_init_printf (_("Saving '%s'"),
+  gimp_progress_init_printf (_("Exporting '%s'"),
                              gimp_filename_to_utf8 (filename));
 
   /* Let's take some file */
diff --git a/plug-ins/file-fli/fli-gimp.c b/plug-ins/file-fli/fli-gimp.c
index ae44e96..c73e428 100644
--- a/plug-ins/file-fli/fli-gimp.c
+++ b/plug-ins/file-fli/fli-gimp.c
@@ -128,10 +128,10 @@ static const GimpParamDef save_args[] =
   { GIMP_PDB_INT32,    "run-mode",     "The run mode { RUN-INTERACTIVE (0), RUN-NONINTERACTIVE (1) }" },
   { GIMP_PDB_IMAGE,    "image",        "Input image" },
   { GIMP_PDB_DRAWABLE, "drawable",     "Input drawable (unused)" },
-  { GIMP_PDB_STRING,   "filename",     "The name of the file to save" },
+  { GIMP_PDB_STRING,   "filename",     "The name of the file to export" },
   { GIMP_PDB_STRING,   "raw-filename", "The name entered" },
-  { GIMP_PDB_INT32,    "from-frame",   "Save beginning from this frame" },
-  { GIMP_PDB_INT32,    "to-frame",     "End saving with this frame" },
+  { GIMP_PDB_INT32,    "from-frame",   "Export beginning from this frame" },
+  { GIMP_PDB_INT32,    "to-frame",     "End exporting with this frame" },
 };
 
 static const GimpParamDef info_args[] =
@@ -155,7 +155,7 @@ static void
 query (void)
 {
   /*
-   * Load/save procedures
+   * Load/export procedures
    */
   gimp_install_procedure (LOAD_PROC,
                          "load FLI-movies",
@@ -178,7 +178,7 @@ query (void)
                                    "");
 
   gimp_install_procedure (SAVE_PROC,
-                         "save FLI-movies",
+                         "export FLI-movies",
                          "This is an experimantal plug-in to handle FLI movies",
                          "Jens Ch. Restemeier",
                          "Jens Ch. Restemeier",
@@ -709,11 +709,11 @@ save_image (const gchar  *filename,
       break;
 
     default:
-      g_message (_("Sorry, I can save only INDEXED and GRAY images."));
+      g_message (_("Sorry, I can export only INDEXED and GRAY images."));
       return FALSE;
     }
 
-  gimp_progress_init_printf (_("Saving '%s'"),
+  gimp_progress_init_printf (_("Exporting '%s'"),
                              gimp_filename_to_utf8 (filename));
 
   /*
diff --git a/plug-ins/file-ico/ico-save.c b/plug-ins/file-ico/ico-save.c
index 9d90c67..26d9c62 100644
--- a/plug-ins/file-ico/ico-save.c
+++ b/plug-ins/file-ico/ico-save.c
@@ -1059,7 +1059,7 @@ ico_save_image (const gchar  *filename,
   IcoFileEntry    *entries;
   gboolean          saved;
 
-  D(("*** Saving Microsoft icon file %s\n", filename));
+  D(("*** Exporting Microsoft icon file %s\n", filename));
 
   ico_save_init (image, &info);
 
@@ -1070,7 +1070,7 @@ ico_save_image (const gchar  *filename,
         return GIMP_PDB_CANCEL;
     }
 
-  gimp_progress_init_printf (_("Saving '%s'"),
+  gimp_progress_init_printf (_("Exporting '%s'"),
                              gimp_filename_to_utf8 (filename));
 
   if (! (fp = g_fopen (filename, "wb")))
diff --git a/plug-ins/file-jpeg/jpeg-save.c b/plug-ins/file-jpeg/jpeg-save.c
index 10dd802..30d2ae5 100644
--- a/plug-ins/file-jpeg/jpeg-save.c
+++ b/plug-ins/file-jpeg/jpeg-save.c
@@ -90,7 +90,7 @@ typedef struct
   guint         source_id;
 } PreviewPersistent;
 
-/*le added : struct containing pointers to save dialog*/
+/*le added : struct containing pointers to export dialog*/
 typedef struct
 {
   gboolean       run;
@@ -282,7 +282,7 @@ save_image (const gchar  *filename,
   buffer = gimp_drawable_get_buffer (drawable_ID);
 
   if (! preview)
-    gimp_progress_init_printf (_("Saving '%s'"),
+    gimp_progress_init_printf (_("Exporting '%s'"),
                                gimp_filename_to_utf8 (filename));
 
   /* Step 1: allocate and initialize JPEG compression object */
diff --git a/plug-ins/common/file-gbr.c b/plug-ins/common/file-gbr.c
index 479fd4e..eccde9c 100644
--- a/plug-ins/common/file-gbr.c
+++ b/plug-ins/common/file-gbr.c
@@ -17,7 +17,7 @@
 
 /*
  * gbr plug-in version 1.00
  * Loads/saves version 2 GIMP .gbr files, by Tim Newsome <drz frody bloke com>
  * Some bits stolen from the .99.7 source tree.
  *
  * Added in GBR version 1 support after learning that there wasn't a
@@ -115,9 +115,9 @@ query (void)
   {
     { GIMP_PDB_INT32,    "run-mode",    "The run mode { RUN-INTERACTIVE (0), RUN-NONINTERACTIVE (1) }" },
     { GIMP_PDB_IMAGE,    "image",       "Input image" },
-    { GIMP_PDB_DRAWABLE, "drawable",    "Drawable to save" },
-    { GIMP_PDB_STRING,   "uri",         "The URI of the file to save the image in" },
-    { GIMP_PDB_STRING,   "raw-uri",     "The URI of the file to save the image in" },
+    { GIMP_PDB_DRAWABLE, "drawable",    "Drawable to export" },
+    { GIMP_PDB_STRING,   "uri",         "The URI of the file to export the image in" },
+    { GIMP_PDB_STRING,   "raw-uri",     "The URI of the file to export the image in" },
     { GIMP_PDB_INT32,    "spacing",     "Spacing of the brush" },
     { GIMP_PDB_STRING,   "description", "Short description of the brush" }
   };
@@ -145,8 +145,8 @@ query (void)
                                     "20, string, GIMP");
 
   gimp_install_procedure (SAVE_PROC,
-                          "Saves files in the GIMP brush file format",
-                          "Saves files in the GIMP brush file format",
+                          "Exports files in the GIMP brush file format",
+                          "Exports files in the GIMP brush file format",
                           "Tim Newsome, Jens Lautenbacher, Sven Neumann",
                           "Tim Newsome, Jens Lautenbacher, Sven Neumann",
                           "1997-2000",
@@ -686,7 +686,7 @@ save_image (GFile   *file,
 
   bpp = babl_format_get_bytes_per_pixel (format);
 
-  gimp_progress_init_printf (_("Saving '%s'"),
+  gimp_progress_init_printf (_("Exporting '%s'"),
                              g_file_get_parse_name (file));
 
   output = G_OUTPUT_STREAM (g_file_replace (file,
@@ -17,7 +17,7 @@
 /*
  * gbr plug-in version 1.00
- * Loads/saves version 2 GIMP .gbr files, by Tim Newsome <drz frody bloke com>
+ * Loads/exports version 2 GIMP .gbr files, by Tim Newsome <drz frody bloke com>
  * Some bits stolen from the .99.7 source tree.
  *
diff --git a/plug-ins/common/file-gif-save.c b/plug-ins/common/file-gif-save.c
index 8726894..aa73956 100644
--- a/plug-ins/common/file-gif-save.c
+++ b/plug-ins/common/file-gif-save.c
@@ -1,4 +1,4 @@
 /* GIF saving file filter for GIMP
  *
  *    Copyright
  *    - Adam D. Moss
@@ -131,11 +131,11 @@ MAIN ()
 
 #define COMMON_SAVE_ARGS \
     { GIMP_PDB_INT32,    "run-mode",        "The run mode { RUN-INTERACTIVE (0), RUN-NONINTERACTIVE (1) }" 
}, \
-    { GIMP_PDB_IMAGE,    "image",           "Image to save" }, \
-    { GIMP_PDB_DRAWABLE, "drawable",        "Drawable to save" }, \
-    { GIMP_PDB_STRING,   "filename",        "The name of the file to save the image in" }, \
+    { GIMP_PDB_IMAGE,    "image",           "Image to export" }, \
+    { GIMP_PDB_DRAWABLE, "drawable",        "Drawable to export" }, \
+    { GIMP_PDB_STRING,   "filename",        "The name of the file to export the image in" }, \
     { GIMP_PDB_STRING,   "raw-filename",    "The name entered" }, \
-    { GIMP_PDB_INT32,    "interlace",       "Try to save as interlaced" }, \
+    { GIMP_PDB_INT32,    "interlace",       "Try to export as interlaced" }, \
     { GIMP_PDB_INT32,    "loop",            "(animated gif) loop infinitely" }, \
     { GIMP_PDB_INT32,    "default-delay",   "(animated gif) Default delay between framese in milliseconds" 
}, \
     { GIMP_PDB_INT32,    "default-dispose", "(animated gif) Default disposal type (0=`don't care`, 
1=combine, 2=replace)" }
@@ -151,16 +151,16 @@ query (void)
   static const GimpParamDef save2_args[] =
   {
     COMMON_SAVE_ARGS,
-    { GIMP_PDB_INT32,    "as-animation", "Save GIF as animation?" },
+    { GIMP_PDB_INT32,    "as-animation", "Export GIF as animation?" },
     { GIMP_PDB_INT32,    "force-delay", "(animated gif) Use specified delay for all frames?" },
     { GIMP_PDB_INT32,    "force-dispose", "(animated gif) Use specified disposal for all frames?" }
   };
 
   gimp_install_procedure (SAVE_PROC,
-                          "saves files in Compuserve GIF file format",
-                          "Save a file in Compuserve GIF format, with "
+                          "exports files in Compuserve GIF file format",
+                          "Export a file in Compuserve GIF format, with "
                           "possible animation, transparency, and comment.  "
-                          "To save an animation, operate on a multi-layer "
+                          "To export an animation, operate on a multi-layer "
                           "file.  The plug-in will interpret <50% alpha as "
                           "transparent.  When run non-interactively, the "
                           "value for the comment is taken from the "
@@ -175,10 +175,10 @@ query (void)
                           save_args, NULL);
 
   gimp_install_procedure (SAVE2_PROC,
-                          "saves files in Compuserve GIF file format",
-                          "Save a file in Compuserve GIF format, with "
+                          "exports files in Compuserve GIF file format",
+                          "Export a file in Compuserve GIF format, with "
                           "possible animation, transparency, and comment.  "
-                          "To save an animation, operate on a multi-layer "
+                          "To export an animation, operate on a multi-layer "
                           "file and give the 'as-animation' parameter "
                           "as TRUE.  The plug-in will interpret <50% "
                           "alpha as transparent.  When run "
@@ -507,7 +507,7 @@ find_unused_ia_color (const guchar *pixels,
       return ((*colors) - 1);
     }
 
-  g_message (_("Couldn't simply reduce colors further. Saving as opaque."));
+  g_message (_("Couldn't simply reduce colors further. Exporting as opaque."));
 
   return -1;
 }
@@ -622,7 +622,7 @@ sanity_check (const gchar  *filename,
   if (image_width > G_MAXUSHORT || image_height > G_MAXUSHORT)
     {
       g_set_error (error, 0, 0,
-                   _("Unable to save '%s'.  "
+                   _("Unable to export '%s'.  "
                    "The GIF file format does not support images that are "
                    "more than %d pixels wide or tall."),
                    gimp_filename_to_utf8 (filename), G_MAXUSHORT);
@@ -796,7 +796,7 @@ save_image (const gchar *filename,
       break;
 
     default:
-      g_message (_("Cannot save RGB color images. Convert to "
+      g_message (_("Cannot export RGB color images. Convert to "
                    "indexed color or grayscale first."));
       return FALSE;
     }
@@ -821,7 +821,7 @@ save_image (const gchar *filename,
 
 
   /* init the progress meter */
-  gimp_progress_init_printf (_("Saving '%s'"),
+  gimp_progress_init_printf (_("Exporting '%s'"),
                              gimp_filename_to_utf8 (filename));
 
 
@@ -1012,7 +1012,7 @@ bad_bounds_dialog (void)
 
   dialog = gtk_message_dialog_new (NULL, 0,
                                    GTK_MESSAGE_WARNING, GTK_BUTTONS_NONE,
-                                   _("The image you are trying to save as a "
+                                   _("The image you are trying to export as a "
                                      "GIF contains layers which extend beyond "
                                      "the actual borders of the image."));
 
@@ -1033,7 +1033,7 @@ bad_bounds_dialog (void)
                                               "allow this.  You may choose "
                                               "whether to crop all of the "
                                               "layers to the image borders, "
-                                              "or cancel this save."));
+                                              "or cancel this export."));
 
   gtk_widget_show (dialog);
 
@@ -1,4 +1,4 @@
-/* GIF saving file filter for GIMP
+/* GIF exporting file filter for GIMP
  *
  *    Copyright
diff --git a/plug-ins/common/file-gih.c b/plug-ins/common/file-gih.c
index 08aac10..968fa2b 100644
--- a/plug-ins/common/file-gih.c
+++ b/plug-ins/common/file-gih.c
@@ -1,4 +1,4 @@
 /* Plug-in to load and save .gih (GIMP Brush Pipe) files.
  *
  * Copyright (C) 1999 Tor Lillqvist
  * Copyright (C) 2000 Jens Lautenbacher, Sven Neumann
@@ -59,7 +59,7 @@
 #define PLUG_IN_ROLE   "gimp-file-gih"
 
 
 /* Parameters applicable each time we save a gih, saved in the
  * main gimp application between invocations of this plug-in.
  */
 typedef struct
@@ -153,9 +153,9 @@ query (void)
   {
     { GIMP_PDB_INT32,       "run-mode",     "The run mode { RUN-INTERACTIVE (0), RUN-NONINTERACTIVE (1) }" },
     { GIMP_PDB_IMAGE,       "image",        "Input image" },
-    { GIMP_PDB_DRAWABLE,    "drawable",     "Drawable to save" },
-    { GIMP_PDB_STRING,      "uri",          "The URI of the file to save the brush pipe in" },
-    { GIMP_PDB_STRING,      "raw-uri",      "The URI of the file to save the brush pipe in" },
+    { GIMP_PDB_DRAWABLE,    "drawable",     "Drawable to export" },
+    { GIMP_PDB_STRING,      "uri",          "The URI of the file to export the brush pipe in" },
+    { GIMP_PDB_STRING,      "raw-uri",      "The URI of the file to export the brush pipe in" },
     { GIMP_PDB_INT32,       "spacing",      "Spacing of the brush" },
     { GIMP_PDB_STRING,      "description",  "Short description of the brush pipe" },
     { GIMP_PDB_INT32,       "cell-width",   "Width of the brush cells" },
@@ -200,8 +200,8 @@ query (void)
   gimp_register_magic_load_handler (LOAD_PROC, "gih", "", "");
 
   gimp_install_procedure (SAVE_PROC,
-                          "saves images in GIMP brush pipe format",
-                          "This plug-in saves an image in the GIMP brush pipe "
+                          "exports images in GIMP brush pipe format",
+                          "This plug-in exports an image in the GIMP brush pipe "
                           "format. For a colored brush pipe, RGBA layers are "
                           "used, otherwise the layers should be grayscale "
                           "masks. The image can be multi-layered, and "
@@ -1291,7 +1291,7 @@ gih_save_image (GFile    *file,
   imagew = gimp_image_width (image_ID);
   imageh = gimp_image_height (image_ID);
 
-  gimp_progress_init_printf (_("Saving '%s'"),
+  gimp_progress_init_printf (_("Exporting '%s'"),
                              g_file_get_parse_name (file));
 
   output = G_OUTPUT_STREAM (g_file_replace (file,
@@ -1,4 +1,4 @@
-/* Plug-in to load and save .gih (GIMP Brush Pipe) files.
+/* Plug-in to load and export .gih (GIMP Brush Pipe) files.
  *
  * Copyright (C) 1999 Tor Lillqvist
@@ -59,7 +59,7 @@
 
 
-/* Parameters applicable each time we save a gih, saved in the
+/* Parameters applicable each time we export a gih, exported in the
  * main gimp application between invocations of this plug-in.
  */
diff --git a/plug-ins/common/file-html-table.c b/plug-ins/common/file-html-table.c
index 7a7eccd..92c771f 100644
--- a/plug-ins/common/file-html-table.c
+++ b/plug-ins/common/file-html-table.c
@@ -2,7 +2,7 @@
  * Copyright (C) 1995 Spencer Kimball and Peter Mattis
  *
  * GTM plug-in --- GIMP Table Magic
- * Allows images to be saved as HTML tables with different colored cells.
+ * Allows images to be exported as HTML tables with different colored cells.
  * It doesn't  have very much practical use other than being able to
  * easily design a table by "painting" it in GIMP, or to make small HTML
  * table images/icons.
@@ -139,9 +139,9 @@ query (void)
   {
     { GIMP_PDB_INT32,    "run-mode",     "The run mode { RUN-INTERACTIVE (0) }" },
     { GIMP_PDB_IMAGE,    "image",        "Input image" },
-    { GIMP_PDB_DRAWABLE, "drawable",     "Drawable to save" },
-    { GIMP_PDB_STRING,   "filename",     "The name of the file to save the image in" },
-    { GIMP_PDB_STRING,   "raw-filename", "The name of the file to save the image in" }
+    { GIMP_PDB_DRAWABLE, "drawable",     "Drawable to export" },
+    { GIMP_PDB_STRING,   "filename",     "The name of the file to export the image in" },
+    { GIMP_PDB_STRING,   "raw-filename", "The name of the file to export the image in" }
   };
 
   gimp_install_procedure (SAVE_PROC,
@@ -233,7 +233,7 @@ save_image (GFile       *file,
   cols = gegl_buffer_get_width  (buffer);
   rows = gegl_buffer_get_height (buffer);
 
-  gimp_progress_init_printf (_("Saving '%s'"),
+  gimp_progress_init_printf (_("Exporting '%s'"),
                              gimp_file_get_utf8_name (file));
 
   output = G_OUTPUT_STREAM (g_file_replace (file,
@@ -731,7 +731,7 @@ color_comp (guchar *buf,
           buf[2] == buf2[2]);
 }
 
 /*  Save interface functions  */
 
 static void
 entry_changed_callback (GtkEntry *entry,
@@ -731,7 +731,7 @@ color_comp (guchar *buf,
 }
 
-/*  Save interface functions  */
+/*  Export interface functions  */
 
 static void
diff --git a/plug-ins/common/file-pat.c b/plug-ins/common/file-pat.c
index 81c957f..2d718fa 100644
--- a/plug-ins/common/file-pat.c
+++ b/plug-ins/common/file-pat.c
@@ -1,6 +1,6 @@
 /*
  * pat plug-in version 1.01
  * Loads/saves version 1 GIMP .pat files, by Tim Newsome <drz frody bloke com>
  *
  * GIMP - The GNU Image Manipulation Program
  * Copyright (C) 1995 Spencer Kimball and Peter Mattis
@@ -87,9 +87,9 @@ query (void)
   {
     { GIMP_PDB_INT32,    "run-mode",    "The run mode { RUN-INTERACTIVE (0), RUN-NONINTERACTIVE (1) }"     },
     { GIMP_PDB_IMAGE,    "image",       "Input image"                      },
-    { GIMP_PDB_DRAWABLE, "drawable",    "Drawable to save"                 },
-    { GIMP_PDB_STRING,   "uri",         "The URI of the file to save the image in" },
-    { GIMP_PDB_STRING,   "raw-uri",     "The URI of the file to save the image in" },
+    { GIMP_PDB_DRAWABLE, "drawable",    "Drawable to export"                 },
+    { GIMP_PDB_STRING,   "uri",         "The URI of the file to export the image in" },
+    { GIMP_PDB_STRING,   "raw-uri",     "The URI of the file to export the image in" },
     { GIMP_PDB_STRING,   "description", "Short description of the pattern" }
   };
 
@@ -117,8 +117,8 @@ query (void)
                                     "20,string,GPAT");
 
   gimp_install_procedure (SAVE_PROC,
-                          "Saves Gimp pattern file (.PAT)",
-                          "New Gimp patterns can be created by saving them "
+                          "Exports Gimp pattern file (.PAT)",
+                          "New Gimp patterns can be created by exporting them "
                           "in the appropriate place with this plug-in.",
                           "Tim Newsome",
                           "Tim Newsome",
@@ -530,7 +530,7 @@ save_image (GFile   *file,
       return FALSE;
     }
 
-  gimp_progress_init_printf (_("Saving '%s'"),
+  gimp_progress_init_printf (_("Exporting '%s'"),
                              g_file_get_parse_name (file));
 
   output = G_OUTPUT_STREAM (g_file_replace (file,
@@ -1,6 +1,6 @@
 /*
  * pat plug-in version 1.01
- * Loads/saves version 1 GIMP .pat files, by Tim Newsome <drz frody bloke com>
+ * Loads/exports version 1 GIMP .pat files, by Tim Newsome <drz frody bloke com>
  *
  * GIMP - The GNU Image Manipulation Program
diff --git a/plug-ins/common/file-pcx.c b/plug-ins/common/file-pcx.c
index d0e2be1..531ef5d 100644
--- a/plug-ins/common/file-pcx.c
+++ b/plug-ins/common/file-pcx.c
@@ -1,5 +1,5 @@
 /*
  * pcx.c GIMP plug-in for loading & saving PCX files
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -120,8 +120,8 @@ query (void)
   {
     { GIMP_PDB_INT32,    "run-mode",     "The run mode { RUN-INTERACTIVE (0), RUN-NONINTERACTIVE (1) }" },
     { GIMP_PDB_IMAGE,    "image",        "Input image"                  },
-    { GIMP_PDB_DRAWABLE, "drawable",     "Drawable to save"             },
-    { GIMP_PDB_STRING,   "filename",     "The name of the file to save the image in" },
+    { GIMP_PDB_DRAWABLE, "drawable",     "Drawable to export"           },
+    { GIMP_PDB_STRING,   "filename",     "The name of the file to export the image in" },
     { GIMP_PDB_STRING,   "raw-filename", "The name entered"             }
   };
 
@@ -145,7 +145,7 @@ query (void)
                                     "0&,byte,10,2&,byte,1,3&,byte,>0,3,byte,<9");
 
   gimp_install_procedure (SAVE_PROC,
-                          "Saves files in ZSoft PCX file format",
+                          "Exports files in ZSoft PCX file format",
                           "FIXME: write help for pcx_save",
                           "Francisco Bustamante & Nick Lamb",
                           "Nick Lamb <njl195 zepler org uk>",
@@ -657,7 +657,7 @@ save_image (const gchar  *filename,
   width  = gegl_buffer_get_width  (buffer);
   height = gegl_buffer_get_height (buffer);
 
-  gimp_progress_init_printf (_("Saving '%s'"),
+  gimp_progress_init_printf (_("Exporting '%s'"),
                              gimp_filename_to_utf8 (filename));
 
   pcx_header.manufacturer = 0x0a;
@@ -692,7 +692,7 @@ save_image (const gchar  *filename,
       break;
 
     default:
-      g_message (_("Cannot save images with alpha channel."));
+      g_message (_("Cannot export images with alpha channel."));
       return FALSE;
   }
 
@@ -1,5 +1,5 @@
 /*
- * pcx.c GIMP plug-in for loading & saving PCX files
+ * pcx.c GIMP plug-in for loading & exporting PCX files
  *
  * This program is free software: you can redistribute it and/or modify
diff --git a/plug-ins/common/file-png.c b/plug-ins/common/file-png.c
index 55e7bb2..70d6eaa 100644
--- a/plug-ins/common/file-png.c
+++ b/plug-ins/common/file-png.c
@@ -28,10 +28,10 @@
  *   load_image()                - Load a PNG image into a new image window.
  *   offsets_dialog()            - Asks the user about offsets when loading.
  *   respin_cmap()               - Re-order a Gimp colormap for PNG tRNS
  *   save_image()                - Save the specified image to a PNG file.
  *   save_compression_callback() - Update the image compression level.
  *   save_interlace_update()     - Update the interlacing option.
  *   save_dialog()               - Pop up the save dialog.
  *
  * Revision History:
  *
@@ -236,9 +236,9 @@ query (void)
 #define COMMON_SAVE_ARGS \
     { GIMP_PDB_INT32,    "run-mode",     "The run mode { RUN-INTERACTIVE (0), RUN-NONINTERACTIVE (1) }" }, \
     { GIMP_PDB_IMAGE,    "image",        "Input image"                  }, \
-    { GIMP_PDB_DRAWABLE, "drawable",     "Drawable to save"             }, \
-    { GIMP_PDB_STRING,   "filename",     "The name of the file to save the image in"}, \
-    { GIMP_PDB_STRING,   "raw-filename", "The name of the file to save the image in"}
+    { GIMP_PDB_DRAWABLE, "drawable",     "Drawable to export"           }, \
+    { GIMP_PDB_STRING,   "filename",     "The name of the file to export the image in"}, \
+    { GIMP_PDB_STRING,   "raw-filename", "The name of the file to export the image in"}
 
 #define OLD_CONFIG_ARGS \
     { GIMP_PDB_INT32, "interlace",   "Use Adam7 interlacing?"            }, \
@@ -303,8 +303,8 @@ query (void)
                                     "png", "", "0,string,\211PNG\r\n\032\n");
 
   gimp_install_procedure (SAVE_PROC,
-                          "Saves files in PNG file format",
-                          "This plug-in saves Portable Network Graphics "
+                          "Exports files in PNG file format",
+                          "This plug-in exports Portable Network Graphics "
                           "(PNG) files.",
                           "Michael Sweet <mike easysw com>, "
                           "Daniel Skarda <0rfelyus atrey karlin mff cuni cz>",
@@ -319,8 +319,8 @@ query (void)
                           save_args, NULL);
 
   gimp_install_procedure (SAVE2_PROC,
-                          "Saves files in PNG file format",
-                          "This plug-in saves Portable Network Graphics "
+                          "Exports files in PNG file format",
+                          "This plug-in exports Portable Network Graphics "
                           "(PNG) files. "
                           "This procedure adds 2 extra parameters to "
                           "file-png-save that control whether "
@@ -339,8 +339,8 @@ query (void)
                           save_args2, NULL);
 
   gimp_install_procedure (SAVE_DEFAULTS_PROC,
-                          "Saves files in PNG file format",
-                          "This plug-in saves Portable Network Graphics (PNG) "
+                          "Exports files in PNG file format",
+                          "This plug-in exports Portable Network Graphics (PNG) "
                           "files, using the default settings stored as "
                           "a parasite.",
                           "Michael Sweet <mike easysw com>, "
@@ -360,10 +360,10 @@ query (void)
 
   gimp_install_procedure (GET_DEFAULTS_PROC,
                           "Get the current set of defaults used by the "
-                          "PNG file save plug-in",
+                          "PNG file export plug-in",
                           "This procedure returns the current set of "
                           "defaults stored as a parasite for the PNG "
-                          "save plug-in. "
+                          "export plug-in. "
                           "These defaults are used to seed the UI, by the "
                           "file_png_save_defaults procedure, and by "
                           "gimp_file_save when it detects to use PNG.",
@@ -381,9 +381,9 @@ query (void)
 
   gimp_install_procedure (SET_DEFAULTS_PROC,
                           "Set the current set of defaults used by the "
-                          "PNG file save plug-in",
+                          "PNG file export plug-in",
                           "This procedure set the current set of defaults "
-                          "stored as a parasite for the PNG save plug-in. "
+                          "stored as a parasite for the PNG export plug-in. "
                           "These defaults are used to seed the UI, by the "
                           "file_png_save_defaults procedure, and by "
                           "gimp_file_save when it detects to use PNG.",
@@ -860,7 +860,7 @@ load_image (const gchar  *filename,
          versions do not match. */
 
       g_set_error (error, 0, 0,
-                   _("Error creating PNG read struct while saving '%s'."),
+                   _("Error creating PNG read struct while exporting '%s'."),
                    gimp_filename_to_utf8 (filename));
       return -1;
     }
@@ -1416,7 +1416,7 @@ offsets_dialog (gint offset_x,
 }
 
 /*
  * 'save_image ()' - Save the specified image to a PNG file.
  */
 
 static gboolean
@@ -1470,7 +1470,7 @@ save_image (const gchar  *filename,
          versions do not match. */
 
       g_set_error (error, 0, 0,
-                   _("Error creating PNG write struct while saving '%s'."),
+                   _("Error creating PNG write struct while exporting '%s'."),
                    gimp_filename_to_utf8 (filename));
       return FALSE;
     }
@@ -1480,7 +1480,7 @@ save_image (const gchar  *filename,
   if (setjmp (png_jmpbuf (pp)))
     {
       g_set_error (error, 0, 0,
-                   _("Error while saving '%s'. Could not save image."),
+                   _("Error while exporting '%s'. Could not export image."),
                    gimp_filename_to_utf8 (filename));
       return FALSE;
     }
@@ -1494,7 +1494,7 @@ save_image (const gchar  *filename,
    * Open the file and initialize the PNG write "engine"...
    */
 
-  gimp_progress_init_printf (_("Saving '%s'"),
+  gimp_progress_init_printf (_("Exporting '%s'"),
                              gimp_filename_to_utf8 (filename));
 
   fp = g_fopen (filename, "wb");
@@ -1578,7 +1578,7 @@ save_image (const gchar  *filename,
       break;
 
     default:
-      g_set_error (error, 0, 0, "Image type can't be saved as PNG");
+      g_set_error (error, 0, 0, "Image type can't be exported as PNG");
       return FALSE;
     }
 
@@ -1820,7 +1820,7 @@ save_image (const gchar  *filename,
     png_set_packing (pp);
 
   /*
    * Allocate memory for "tile_height" rows and save the image...
    */
 
   tile_height = gimp_tile_height ();
@@ -28,10 +28,10 @@
  *   offsets_dialog()            - Asks the user about offsets when loading.
  *   respin_cmap()               - Re-order a Gimp colormap for PNG tRNS
- *   save_image()                - Save the specified image to a PNG file.
+ *   save_image()                - Export the specified image to a PNG file.
  *   save_compression_callback() - Update the image compression level.
  *   save_interlace_update()     - Update the interlacing option.
@@ -28,10 +28,10 @@
  *   save_compression_callback() - Update the image compression level.
  *   save_interlace_update()     - Update the interlacing option.
- *   save_dialog()               - Pop up the save dialog.
+ *   save_dialog()               - Pop up the export dialog.
  *
  * Revision History:
@@ -1416,7 +1416,7 @@ offsets_dialog (gint offset_x,
 
 /*
- * 'save_image ()' - Save the specified image to a PNG file.
+ * 'save_image ()' - Export the specified image to a PNG file.
  */
 
@@ -1820,7 +1820,7 @@ save_image (const gchar  *filename,
 
   /*
-   * Allocate memory for "tile_height" rows and save the image...
+   * Allocate memory for "tile_height" rows and export the image...
    */
 
diff --git a/plug-ins/common/file-ps.c b/plug-ins/common/file-ps.c
index 7f8c5d2..36583cb 100644
--- a/plug-ins/common/file-ps.c
+++ b/plug-ins/common/file-ps.c
@@ -630,9 +630,9 @@ query (void)
   {
     { GIMP_PDB_INT32,    "run-mode",     "The run mode { RUN-INTERACTIVE (0), RUN-NONINTERACTIVE (1) }" },
     { GIMP_PDB_IMAGE,    "image",        "Input image" },
-    { GIMP_PDB_DRAWABLE, "drawable",     "Drawable to save" },
-    { GIMP_PDB_STRING,   "filename",     "The name of the file to save the image in" },
-    { GIMP_PDB_STRING,   "raw-filename", "The name of the file to save the image in" },
+    { GIMP_PDB_DRAWABLE, "drawable",     "Drawable to export" },
+    { GIMP_PDB_STRING,   "filename",     "The name of the file to export the image in" },
+    { GIMP_PDB_STRING,   "raw-filename", "The name of the file to export the image in" },
     { GIMP_PDB_FLOAT,    "width",        "Width of the image in PostScript file (0: use input image size)" },
     { GIMP_PDB_FLOAT,    "height",       "Height of image in PostScript file (0: use input image size)" },
     { GIMP_PDB_FLOAT,    "x-offset",     "X-offset to image from lower left corner" },
@@ -737,8 +737,8 @@ query (void)
 #endif
 
   gimp_install_procedure (SAVE_PS_PROC,
-                          "save image as PostScript docuement",
-                          "PostScript saving handles all image types except "
+                          "export image as PostScript document",
+                          "PostScript exporting handles all image types except "
                           "those with alpha channels.",
                           "Peter Kirchgessner <peter kirchgessner net>",
                           "Peter Kirchgessner",
@@ -754,8 +754,8 @@ query (void)
   gimp_register_save_handler (SAVE_PS_PROC, "ps", "");
 
   gimp_install_procedure (SAVE_EPS_PROC,
-                          "save image as Encapsulated PostScript image",
-                          "PostScript saving handles all image types except "
+                          "export image as Encapsulated PostScript image",
+                          "PostScript exporting handles all image types except "
                           "those with alpha channels.",
                           "Peter Kirchgessner <peter kirchgessner net>",
                           "Peter Kirchgessner",
@@ -1240,11 +1240,11 @@ save_image (GFile   *file,
 
   drawable_type = gimp_drawable_type (drawable_ID);
 
   /*  Make sure we're not saving an image with an alpha channel  */
   if (gimp_drawable_has_alpha (drawable_ID))
     {
       g_set_error (error, G_FILE_ERROR, G_FILE_ERROR_FAILED,
-                   _("PostScript save cannot handle images with alpha channels"));
+                   _("PostScript export cannot handle images with alpha channels"));
       return FALSE;
     }
 
@@ -1262,7 +1262,7 @@ save_image (GFile   *file,
       break;
     }
 
-  gimp_progress_init_printf (_("Saving '%s'"),
+  gimp_progress_init_printf (_("Exporting '%s'"),
                              gimp_file_get_utf8_name (file));
 
   output = G_OUTPUT_STREAM (g_file_replace (file,
@@ -1240,11 +1240,11 @@ save_image (GFile   *file,
   drawable_type = gimp_drawable_type (drawable_ID);
 
-  /*  Make sure we're not saving an image with an alpha channel  */
+  /*  Make sure we're not exporting an image with an alpha channel  */
   if (gimp_drawable_has_alpha (drawable_ID))
     {
diff --git a/plug-ins/common/file-psp.c b/plug-ins/common/file-psp.c
index b35ff8c..3c6168b 100644
--- a/plug-ins/common/file-psp.c
+++ b/plug-ins/common/file-psp.c
@@ -1,4 +1,4 @@
 /* GIMP plug-in to load and save Paint Shop Pro files (.PSP and .TUB)
  *
  * Copyright (C) 1999 Tor Lillqvist
  *
@@ -18,7 +18,7 @@
 
 /*
  *
  * Work in progress! Doesn't handle saving yet.
  *
  * For a copy of the PSP file format documentation, surf to
  * http://www.jasc.com.
@@ -580,18 +580,18 @@ query (void)
   {
     { GIMP_PDB_INT32,    "run-mode",     "The run mode { RUN-INTERACTIVE (0), RUN-NONINTERACTIVE (1) }" },
     { GIMP_PDB_IMAGE,    "image",        "Input image" },
-    { GIMP_PDB_DRAWABLE, "drawable",     "Drawable to save" },
-    { GIMP_PDB_STRING,   "filename",     "The name of the file to save the image in" },
-    { GIMP_PDB_STRING,   "raw-filename", "The name of the file to save the image in" },
+    { GIMP_PDB_DRAWABLE, "drawable",     "Drawable to export" },
+    { GIMP_PDB_STRING,   "filename",     "The name of the file to export the image in" },
+    { GIMP_PDB_STRING,   "raw-filename", "The name of the file to export the image in" },
     { GIMP_PDB_INT32,    "compression",  "Specify 0 for no compression, 1 for RLE, and 2 for LZ77" }
   };
 #endif
 
   gimp_install_procedure (LOAD_PROC,
                           "loads images from the Paint Shop Pro PSP file format",
-                          "This plug-in loads and saves images in "
+                          "This plug-in loads and exports images in "
                           "Paint Shop Pro's native PSP format. "
-                          "Vector layers aren't handled. Saving isn't "
+                          "Vector layers aren't handled. Exporting isn't "
                           "yet implemented.",
                           "Tor Lillqvist",
                           "Tor Lillqvist",
@@ -609,13 +609,13 @@ query (void)
                                     "",
                                     "0,string,Paint\\040Shop\\040Pro\\040Image\\040File\n\032");
 
   /* commented out until saving is implemented */
 #if 0
   gimp_install_procedure (SAVE_PROC,
-                          "saves images in the Paint Shop Pro PSP file format",
-                          "This plug-in loads and saves images in "
+                          "exports images in the Paint Shop Pro PSP file format",
+                          "This plug-in loads and exports images in "
                           "Paint Shop Pro's native PSP format. "
-                          "Vector layers aren't handled. Saving isn't "
+                          "Vector layers aren't handled. Exporting isn't "
                           "yet implemented.",
                           "Tor Lillqvist",
                           "Tor Lillqvist",
@@ -1641,7 +1641,7 @@ read_tube_block (FILE     *f,
 
   /* We use a parasite to pass in the tube (pipe) parameters in
    * case we will have any use of those, for instance in the gpb
    * plug-in that saves a GIMP image pipe.
    */
   params.dim = 1;
   params.cellwidth = ia->width / params.cols;
@@ -1889,7 +1889,7 @@ save_image (const gchar  *filename,
             gint32        drawable_ID,
             GError      **error)
 {
-  g_message ("Saving not implemented yet");
+  g_message ("Exporting not implemented yet");
 
   return FALSE;
 }
@@ -1,4 +1,4 @@
-/* GIMP plug-in to load and save Paint Shop Pro files (.PSP and .TUB)
+/* GIMP plug-in to load and export Paint Shop Pro files (.PSP and .TUB)
  *
  * Copyright (C) 1999 Tor Lillqvist
@@ -18,7 +18,7 @@
 /*
  *
- * Work in progress! Doesn't handle saving yet.
+ * Work in progress! Doesn't handle exporting yet.
  *
  * For a copy of the PSP file format documentation, surf to
@@ -609,13 +609,13 @@ query (void)
                                     "0,string,Paint\\040Shop\\040Pro\\040Image\\040File\n\032");
 
-  /* commented out until saving is implemented */
+  /* commented out until exporting is implemented */
 #if 0
   gimp_install_procedure (SAVE_PROC,
@@ -1641,7 +1641,7 @@ read_tube_block (FILE     *f,
   /* We use a parasite to pass in the tube (pipe) parameters in
    * case we will have any use of those, for instance in the gpb
-   * plug-in that saves a GIMP image pipe.
+   * plug-in that exports a GIMP image pipe.
    */
   params.dim = 1;
diff --git a/plug-ins/common/file-sunras.c b/plug-ins/common/file-sunras.c
index 884e8c6..535d2db 100644
--- a/plug-ins/common/file-sunras.c
+++ b/plug-ins/common/file-sunras.c
@@ -205,7 +205,7 @@ const GimpPlugInInfo PLUG_IN_INFO =
 };
 
 
-/* Save info  */
+/* Export info  */
 typedef struct
 {
   gboolean  rle;  /*  rle or standard */
@@ -240,9 +240,9 @@ query (void)
   {
     { GIMP_PDB_INT32,    "run-mode",     "The run mode { RUN-INTERACTIVE (0), RUN-NONINTERACTIVE (1) }" },
     { GIMP_PDB_IMAGE,    "image",        "Input image" },
-    { GIMP_PDB_DRAWABLE, "drawable",     "Drawable to save" },
-    { GIMP_PDB_STRING,   "filename",     "The name of the file to save the image in" },
-    { GIMP_PDB_STRING,   "raw-filename", "The name of the file to save the image in" },
+    { GIMP_PDB_DRAWABLE, "drawable",     "Drawable to export" },
+    { GIMP_PDB_STRING,   "filename",     "The name of the file to export the image in" },
+    { GIMP_PDB_STRING,   "raw-filename", "The name of the file to export the image in" },
     { GIMP_PDB_INT32,    "rle",          "Specify non-zero for rle output, zero for standard output" }
   };
 
@@ -266,8 +266,8 @@ query (void)
                                     "0,long,0x59a66a95");
 
   gimp_install_procedure (SAVE_PROC,
-                          "save file in the SunRaster file format",
-                          "SUNRAS saving handles all image types except "
+                          "export file in the SunRaster file format",
+                          "SUNRAS exporting handles all image types except "
                           "those with alpha channels.",
                           "Peter Kirchgessner",
                           "Peter Kirchgessner",
@@ -579,11 +579,11 @@ save_image (const gchar  *filename,
 
   drawable_type = gimp_drawable_type (drawable_ID);
 
   /*  Make sure we're not saving an image with an alpha channel  */
   if (gimp_drawable_has_alpha (drawable_ID))
     {
       g_set_error (error, G_FILE_ERROR, G_FILE_ERROR_FAILED,
-                   _("SUNRAS save cannot handle images with alpha channels"));
+                   _("SUNRAS export cannot handle images with alpha channels"));
       return FALSE;
     }
 
@@ -599,7 +599,7 @@ save_image (const gchar  *filename,
       break;
     }
 
-  gimp_progress_init_printf (_("Saving '%s'"),
+  gimp_progress_init_printf (_("Exporting '%s'"),
                              gimp_filename_to_utf8 (filename));
 
   /* Open the output file. */
@@ -579,11 +579,11 @@ save_image (const gchar  *filename,
   drawable_type = gimp_drawable_type (drawable_ID);
 
-  /*  Make sure we're not saving an image with an alpha channel  */
+  /*  Make sure we're not exporting an image with an alpha channel  */
   if (gimp_drawable_has_alpha (drawable_ID))
     {
diff --git a/plug-ins/common/file-tga.c b/plug-ins/common/file-tga.c
index 8c67eed..f55168d 100644
--- a/plug-ins/common/file-tga.c
+++ b/plug-ins/common/file-tga.c
@@ -1,7 +1,7 @@
 /* GIMP - The GNU Image Manipulation Program
  * Copyright (C) 1995 Spencer Kimball and Peter Mattis
  *
  * TrueVision Targa loading and saving file filter for GIMP.
  * Targa code Copyright (C) 1997 Raphael FRANCOIS and Gordon Matzigkeit
  *
  * The Targa reading and writing code was written from scratch by
@@ -229,9 +229,9 @@ query (void)
   {
     { GIMP_PDB_INT32,    "run-mode",     "The run mode { RUN-INTERACTIVE (0), RUN-NONINTERACTIVE (1) }" },
     { GIMP_PDB_IMAGE,    "image",        "Input image"                  },
-    { GIMP_PDB_DRAWABLE, "drawable",     "Drawable to save"             },
-    { GIMP_PDB_STRING,   "filename",     "The name of the file to save the image in" },
-    { GIMP_PDB_STRING,   "raw-filename", "The name of the file to save the image in" },
+    { GIMP_PDB_DRAWABLE, "drawable",     "Drawable to export"           },
+    { GIMP_PDB_STRING,   "filename",     "The name of the file to export the image in" },
+    { GIMP_PDB_STRING,   "raw-filename", "The name of the file to export the image in" },
     { GIMP_PDB_INT32,    "rle",          "Use RLE compression"          },
     { GIMP_PDB_INT32,    "origin",       "Image origin (0 = top-left, 1 = bottom-left)"}
   } ;
@@ -256,7 +256,7 @@ query (void)
                                     "-18&,string,TRUEVISION-XFILE.,-1,byte,0");
 
   gimp_install_procedure (SAVE_PROC,
-                          "saves files in the Targa file format",
+                          "exports files in the Targa file format",
                           "FIXME: write help for tga_save",
                           "Raphael FRANCOIS, Gordon Matzigkeit",
                           "Raphael FRANCOIS, Gordon Matzigkeit",
@@ -1195,7 +1195,7 @@ save_image (const gchar  *filename,
   width  = gegl_buffer_get_width  (buffer);
   height = gegl_buffer_get_height (buffer);
 
-  gimp_progress_init_printf (_("Saving '%s'"),
+  gimp_progress_init_printf (_("Exporting '%s'"),
                              gimp_filename_to_utf8 (filename));
 
   if ((fp = g_fopen (filename, "wb")) == NULL)
@@ -1,7 +1,7 @@
  * Copyright (C) 1995 Spencer Kimball and Peter Mattis
  *
- * TrueVision Targa loading and saving file filter for GIMP.
+ * TrueVision Targa loading and exporting file filter for GIMP.
  * Targa code Copyright (C) 1997 Raphael FRANCOIS and Gordon Matzigkeit
  *
diff --git a/plug-ins/common/file-xbm.c b/plug-ins/common/file-xbm.c
index 86a6305..be0c2d7 100644
--- a/plug-ins/common/file-xbm.c
+++ b/plug-ins/common/file-xbm.c
@@ -1,7 +1,7 @@
 /* GIMP - The GNU Image Manipulation Program
  * Copyright (C) 1995 Spencer Kimball and Peter Mattis
  *
  * X10 and X11 bitmap (XBM) loading and saving file filter for GIMP.
  * XBM code Copyright (C) 1998 Gordon Matzigkeit
  *
  * The XBM reading and writing code was written from scratch by Gordon
@@ -64,7 +64,7 @@
 #define DEFAULT_PREFIX "bitmap"
 #define MAX_PREFIX     64
 
 /* Whether or not to save as X10 bitmap. */
 #define DEFAULT_X10_FORMAT FALSE
 
 typedef struct _XBMSaveVals
@@ -162,11 +162,11 @@ query (void)
   {
     { GIMP_PDB_INT32,    "run-mode",       "The run mode { RUN-INTERACTIVE (0), RUN-NONINTERACTIVE (1) }" },
     { GIMP_PDB_IMAGE,    "image",          "Input image" },
-    { GIMP_PDB_DRAWABLE, "drawable",       "Drawable to save" },
-    { GIMP_PDB_STRING,   "filename",       "The name of the file to save" },
+    { GIMP_PDB_DRAWABLE, "drawable",       "Drawable to export" },
+    { GIMP_PDB_STRING,   "filename",       "The name of the file to export" },
     { GIMP_PDB_STRING,   "raw-filename",   "The name entered" },
     { GIMP_PDB_STRING,   "comment",        "Image description (maximum 72 bytes)" },
-    { GIMP_PDB_INT32,    "x10",            "Save in X10 format" },
+    { GIMP_PDB_INT32,    "x10",            "Export in X10 format" },
     { GIMP_PDB_INT32,    "x-hot",          "X coordinate of hotspot" },
     { GIMP_PDB_INT32,    "y-hot",          "Y coordinate of hotspot" },
     { GIMP_PDB_STRING,   "prefix",         "Identifier prefix [determined from filename]"},
@@ -193,8 +193,8 @@ query (void)
                               "");
 
   gimp_install_procedure (SAVE_PROC,
-                          "Save a file in X10 or X11 bitmap (XBM) file format",
-                          "Save a file in X10 or X11 bitmap (XBM) file format.  XBM is a lossless format for 
flat black-and-white (two color indexed) images.",
+                          "Export a file in X10 or X11 bitmap (XBM) file format",
+                          "Export a file in X10 or X11 bitmap (XBM) file format.  XBM is a lossless format 
for flat black-and-white (two color indexed) images.",
                           "Gordon Matzigkeit",
                           "Gordon Matzigkeit",
                           "1998",
@@ -994,7 +994,7 @@ save_image (GFile        *file,
   if (! gimp_drawable_is_indexed (drawable_ID) || colors > 2)
     {
       /* The image is not black-and-white. */
-      g_message (_("The image which you are trying to save as "
+      g_message (_("The image which you are trying to export as "
                    "an XBM contains more than two colors.\n\n"
                    "Please convert it to a black and white "
                    "(1-bit) indexed image and try again."));
@@ -1030,7 +1030,7 @@ save_image (GFile        *file,
         dark = 1;
     }
 
-  gimp_progress_init_printf (_("Saving '%s'"),
+  gimp_progress_init_printf (_("Exporting '%s'"),
                              gimp_file_get_utf8_name (file));
 
   output = G_OUTPUT_STREAM (g_file_replace (file,
@@ -1,7 +1,7 @@
  * Copyright (C) 1995 Spencer Kimball and Peter Mattis
  *
- * X10 and X11 bitmap (XBM) loading and saving file filter for GIMP.
+ * X10 and X11 bitmap (XBM) loading and exporting file filter for GIMP.
  * XBM code Copyright (C) 1998 Gordon Matzigkeit
  *
@@ -64,7 +64,7 @@
 #define MAX_PREFIX     64
 
-/* Whether or not to save as X10 bitmap. */
+/* Whether or not to export as X10 bitmap. */
 #define DEFAULT_X10_FORMAT FALSE
 
diff --git a/plug-ins/common/file-xwd.c b/plug-ins/common/file-xwd.c
index 760bd14..203a497 100644
--- a/plug-ins/common/file-xwd.c
+++ b/plug-ins/common/file-xwd.c
@@ -274,9 +274,9 @@ query (void)
   {
     { GIMP_PDB_INT32,    "run-mode",     "The run mode { RUN-INTERACTIVE (0), RUN-NONINTERACTIVE (1) }" },
     { GIMP_PDB_IMAGE,    "image",        "Input image" },
-    { GIMP_PDB_DRAWABLE, "drawable",     "Drawable to save" },
-    { GIMP_PDB_STRING,   "filename",     "The name of the file to save the image in" },
-    { GIMP_PDB_STRING,   "raw-filename", "The name of the file to save the image in" }
+    { GIMP_PDB_DRAWABLE, "drawable",     "Drawable to export" },
+    { GIMP_PDB_STRING,   "filename",     "The name of the file to export the image in" },
+    { GIMP_PDB_STRING,   "raw-filename", "The name of the file to export the image in" }
   };
 
   gimp_install_procedure (LOAD_PROC,
@@ -301,8 +301,8 @@ query (void)
                                     "4,long,0x00000007");
 
   gimp_install_procedure (SAVE_PROC,
-                          "Saves files in the XWD (X Window Dump) format",
-                          "XWD saving handles all image types except "
+                          "Exports files in the XWD (X Window Dump) format",
+                          "XWD exporting handles all image types except "
                           "those with alpha channels.",
                           "Peter Kirchgessner",
                           "Peter Kirchgessner",
@@ -629,11 +629,11 @@ save_image (GFile   *file,
 
   drawable_type = gimp_drawable_type (drawable_ID);
 
   /*  Make sure we're not saving an image with an alpha channel  */
   if (gimp_drawable_has_alpha (drawable_ID))
     {
       g_set_error_literal (error, G_FILE_ERROR, G_FILE_ERROR_FAILED,
-                           _("Cannot save images with alpha channels."));
+                           _("Cannot export images with alpha channels."));
       return FALSE;
     }
 
@@ -649,7 +649,7 @@ save_image (GFile   *file,
       break;
     }
 
-  gimp_progress_init_printf (_("Saving '%s'"),
+  gimp_progress_init_printf (_("Exporting '%s'"),
                              gimp_file_get_utf8_name (file));
 
   output = G_OUTPUT_STREAM (g_file_replace (file, NULL, FALSE, 0, NULL, error));
@@ -683,7 +683,7 @@ save_image (GFile   *file,
   if (success && ! g_output_stream_close (output, NULL, error))
     {
       g_prefix_error (error,
-                      _("Error saving '%s': "),
+                      _("Error exporting '%s': "),
                       gimp_file_get_utf8_name (file));
       success = FALSE;
     }
@@ -629,11 +629,11 @@ save_image (GFile   *file,
   drawable_type = gimp_drawable_type (drawable_ID);
 
-  /*  Make sure we're not saving an image with an alpha channel  */
+  /*  Make sure we're not exporting an image with an alpha channel  */
   if (gimp_drawable_has_alpha (drawable_ID))
     {
diff --git a/plug-ins/file-fits/fits.c b/plug-ins/file-fits/fits.c
index 5889fe9..265e16e 100644
--- a/plug-ins/file-fits/fits.c
+++ b/plug-ins/file-fits/fits.c
@@ -151,9 +151,9 @@ query (void)
   {
     { GIMP_PDB_INT32,    "run-mode",     "The run mode { RUN-INTERACTIVE (0), RUN-NONINTERACTIVE (1) }" },
     { GIMP_PDB_IMAGE,    "image",        "Input image" },
-    { GIMP_PDB_DRAWABLE, "drawable",     "Drawable to save" },
-    { GIMP_PDB_STRING,   "filename",     "The name of the file to save the image in" },
-    { GIMP_PDB_STRING,   "raw-filename", "The name of the file to save the image in" },
+    { GIMP_PDB_DRAWABLE, "drawable",     "Drawable to export" },
+    { GIMP_PDB_STRING,   "filename",     "The name of the file to export the image in" },
+    { GIMP_PDB_STRING,   "raw-filename", "The name of the file to export the image in" },
   };
 
   gimp_install_procedure (LOAD_PROC,
@@ -177,8 +177,8 @@ query (void)
                                     "0,string,SIMPLE");
 
   gimp_install_procedure (SAVE_PROC,
-                          "save file in the FITS file format",
-                          "FITS saving handles all image types except "
+                          "export file in the FITS file format",
+                          "FITS exporting handles all image types except "
                           "those with alpha channels.",
                           "Peter Kirchgessner",
                           "Peter Kirchgessner (peter kirchgessner net)",
@@ -449,12 +449,12 @@ save_image (const gchar  *filename,
 
   drawable_type = gimp_drawable_type (drawable_ID);
 
   /*  Make sure we're not saving an image with an alpha channel  */
   if (gimp_drawable_has_alpha (drawable_ID))
     {
       g_set_error (error, G_FILE_ERROR, G_FILE_ERROR_FAILED,
                    "%s",
-                   _("FITS save cannot handle images with alpha channels"));
+                   _("FITS export cannot handle images with alpha channels"));
       return FALSE;
     }
 
@@ -470,7 +470,7 @@ save_image (const gchar  *filename,
       break;
     }
 
-  gimp_progress_init_printf (_("Saving '%s'"),
+  gimp_progress_init_printf (_("Exporting '%s'"),
                              gimp_filename_to_utf8 (filename));
 
   /* Open the output file. */
@@ -449,12 +449,12 @@ save_image (const gchar  *filename,
   drawable_type = gimp_drawable_type (drawable_ID);
 
-  /*  Make sure we're not saving an image with an alpha channel  */
+  /*  Make sure we're not exporting an image with an alpha channel  */
   if (gimp_drawable_has_alpha (drawable_ID))
     {
diff --git a/plug-ins/file-psd/psd-save.c b/plug-ins/file-psd/psd-save.c
index 6ceca85..48e2d80 100644
--- a/plug-ins/file-psd/psd-save.c
+++ b/plug-ins/file-psd/psd-save.c
@@ -1,12 +1,12 @@
 /*
  * PSD Save Plugin version 1.0 (BETA)
  * This GIMP plug-in is designed to save Adobe Photoshop(tm) files (.PSD)
  *
  * Monigotes
  *
  *     If this plug-in fails to save a file which you think it should,
  *     please tell me what seemed to go wrong, and anything you know
  *     about the image you tried to save.  Please don't send big PSD
  *     files to me without asking first.
  *
  *          Copyright (C) 2000 Monigotes
@@ -56,7 +56,7 @@
 
 /*
  * TODO:
- *       Save preview
+ *       Export preview
  */
 
 /*
@@ -250,8 +250,8 @@ psd_lmode_layer (gint32  idLayer,
                              gimp_layer_get_mode (idLayer),
                              NULL, &nick, NULL, NULL);
 
-        g_message (_("Unable to save layer with mode '%s'.  Either the PSD "
-                     "file format or the save plug-in does not support that, "
+        g_message (_("Unable to export layer with mode '%s'.  Either the PSD "
+                     "file format or the export plug-in does not support that, "
                      "using normal mode instead."), nick);
 
         IFDBG printf ("PSD: Warning - unsupported layer-blend mode: %s, "
@@ -501,7 +501,7 @@ gimpBaseTypeToPsdMode (GimpImageBaseType gimpBaseType)
       return 2;                                         /* Indexed */
     default:
       g_message (_("Error: Can't convert GIMP base imagetype to PSD mode"));
-      IFDBG printf ("PSD Save: gimpBaseType value is %d, "
+      IFDBG printf ("PSD Export: gimpBaseType value is %d, "
                     "can't convert to PSD mode", gimpBaseType);
       gimp_quit ();
       return 3;                            /* Return RGB by default */
@@ -575,7 +575,7 @@ save_header (FILE   *fd,
                 "channels");
   write_gint32 (fd, PSDImageData.image_height, "rows");
   write_gint32 (fd, PSDImageData.image_width, "columns");
-  write_gint16 (fd, 8, "depth");  /* Saving can only be done in 8 bits at the moment. */
+  write_gint16 (fd, 8, "depth");  /* Exporting can only be done in 8 bits at the moment. */
   write_gint16 (fd, gimpBaseTypeToPsdMode (PSDImageData.baseType), "mode");
 }
 
@@ -1487,7 +1487,7 @@ save_image (const gchar  *filename,
       gimp_image_height (image_id) > 30000)
     {
       g_set_error (error, G_FILE_ERROR, G_FILE_ERROR_FAILED,
-                   _("Unable to save '%s'.  The PSD file format does not "
+                   _("Unable to export '%s'.  The PSD file format does not "
                      "support images that are more than 30,000 pixels wide "
                      "or tall."),
                    gimp_filename_to_utf8 (filename));
@@ -1502,7 +1502,7 @@ save_image (const gchar  *filename,
       if (gegl_buffer_get_width (buffer) > 30000 || gegl_buffer_get_height (buffer) > 30000)
         {
           g_set_error (error, G_FILE_ERROR, G_FILE_ERROR_FAILED,
-                       _("Unable to save '%s'.  The PSD file format does not "
+                       _("Unable to export '%s'.  The PSD file format does not "
                          "support images with layers that are more than 30,000 "
                          "pixels wide or tall."),
                        gimp_filename_to_utf8 (filename));
@@ -1513,7 +1513,7 @@ save_image (const gchar  *filename,
     }
   g_free (layers);
 
-  gimp_progress_init_printf (_("Saving '%s'"),
+  gimp_progress_init_printf (_("Exporting '%s'"),
                              gimp_filename_to_utf8 (filename));
 
   fd = g_fopen (filename, "wb");
@@ -1,12 +1,12 @@
 /*
- * PSD Save Plugin version 1.0 (BETA)
- * This GIMP plug-in is designed to save Adobe Photoshop(tm) files (.PSD)
+ * PSD Export Plugin version 1.0 (BETA)
+ * This GIMP plug-in is designed to export Adobe Photoshop(tm) files (.PSD)
  *
  * Monigotes
@@ -1,12 +1,12 @@
  * Monigotes
  *
- *     If this plug-in fails to save a file which you think it should,
+ *     If this plug-in fails to export a file which you think it should,
  *     please tell me what seemed to go wrong, and anything you know
@@ -1,12 +1,12 @@
  *     please tell me what seemed to go wrong, and anything you know
- *     about the image you tried to save.  Please don't send big PSD
+ *     about the image you tried to export.  Please don't send big PSD
  *     files to me without asking first.
  *
diff --git a/plug-ins/file-sgi/sgi.c b/plug-ins/file-sgi/sgi.c
index abdb312..c3b13a9 100644
--- a/plug-ins/file-sgi/sgi.c
+++ b/plug-ins/file-sgi/sgi.c
@@ -22,9 +22,9 @@
  *   query()                     - Respond to a plug-in query...
  *   run()                       - Run the plug-in...
  *   load_image()                - Load a PNG image into a new image window.
  *   save_image()                - Save the specified image to a PNG file.
  *   save_ok_callback()          - Destroy the save dialog and save the image.
  *   save_dialog()               - Pop up the save dialog.
  *
  */
 
@@ -106,9 +106,9 @@ query (void)
   {
     { GIMP_PDB_INT32,    "run-mode",     "The run mode { RUN-INTERACTIVE (0), RUN-NONINTERACTIVE (1) }" },
     { GIMP_PDB_IMAGE,    "image",        "Input image" },
-    { GIMP_PDB_DRAWABLE, "drawable",     "Drawable to save" },
-    { GIMP_PDB_STRING,   "filename",     "The name of the file to save the image in" },
-    { GIMP_PDB_STRING,   "raw-filename", "The name of the file to save the image in" },
+    { GIMP_PDB_DRAWABLE, "drawable",     "Drawable to export" },
+    { GIMP_PDB_STRING,   "filename",     "The name of the file to export the image in" },
+    { GIMP_PDB_STRING,   "raw-filename", "The name of the file to export the image in" },
     { GIMP_PDB_INT32,    "compression",  "Compression level (0 = none, 1 = RLE, 2 = ARLE)" }
   };
 
@@ -133,8 +133,8 @@ query (void)
                                     "0,short,474");
 
   gimp_install_procedure (SAVE_PROC,
-                          "Saves files in SGI image file format",
-                          "This plug-in saves SGI image files.",
+                          "Exports files in SGI image file format",
+                          "This plug-in exports SGI image files.",
                           "Michael Sweet <mike easysw com>",
                           "Copyright 1997-1998 by Michael Sweet",
                           PLUG_IN_VERSION,
@@ -574,7 +574,7 @@ save_image (const gchar  *filename,
    * Open the file for writing...
    */
 
-  gimp_progress_init_printf (_("Saving '%s'"),
+  gimp_progress_init_printf (_("Exporting '%s'"),
                              gimp_filename_to_utf8 (filename));
 
   sgip = sgiOpen (filename, SGI_WRITE, compression, 1,
@@ -22,9 +22,9 @@
  *   run()                       - Run the plug-in...
  *   load_image()                - Load a PNG image into a new image window.
- *   save_image()                - Save the specified image to a PNG file.
- *   save_ok_callback()          - Destroy the save dialog and save the image.
- *   save_dialog()               - Pop up the save dialog.
+ *   save_image()                - Export the specified image to a PNG file.
+ *   save_ok_callback()          - Destroy the export dialog and export the image.
+ *   save_dialog()               - Pop up the export dialog.
  *
  */
diff --git a/plug-ins/file-tiff/file-tiff-save.c b/plug-ins/file-tiff/file-tiff-save.c
index 4ef6a86..920ab10 100644
--- a/plug-ins/file-tiff/file-tiff-save.c
+++ b/plug-ins/file-tiff/file-tiff-save.c
@@ -1,4 +1,4 @@
 /* tiff saving for GIMP
  *  -Peter Mattis
  *
  * The TIFF loading code has been completely revamped by Nick Lamb
@@ -311,7 +311,7 @@ save_image (const gchar  *filename,
   tile_height = gimp_tile_height ();
   rowsperstrip = tile_height;
 
-  gimp_progress_init_printf (_("Saving '%s'"),
+  gimp_progress_init_printf (_("Exporting '%s'"),
                              gimp_filename_to_utf8 (filename));
 
   drawable_type = gimp_drawable_type (layer);
@@ -479,7 +479,7 @@ save_image (const gchar  *filename,
 
     case GIMP_INDEXEDA_IMAGE:
       g_set_error (error, G_FILE_ERROR, G_FILE_ERROR_FAILED,
-                   _("TIFF save cannot handle indexed images with "
+                   _("TIFF export cannot handle indexed images with "
                      "an alpha channel."));
     default:
       goto out;
@@ -1,4 +1,4 @@
-/* tiff saving for GIMP
+/* tiff exporting for GIMP
  *  -Peter Mattis
  *


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]